// URL to your CSV data on Gist
const csvUrl = 'https://gist.githubusercontent.com/Hemanthh81/cc8fc98028786cd06947944b59da7c0f/raw/52ec95e6f744e536e2c6437ba2dcd1dbe46216f0/Cars_data.csv';

// Function to fetch the CSV data
async function fetchData(url) {
  const response = await fetch(url);
  const data = await response.text();
  return d3.csvParse(data);
}

// Function to create the bar chart
function createBarChart(data) {
  // Extract required data attributes (Make, mpg, attributes) from the CSV data
  const barChartData = data.map((d) => ({
    make: d.Make,
    mpg: +d.mpg,
    attributes: +d.attributes,
  }));

  // Set up the dimensions for the chart
  const margin = { top: 20, right: 20, bottom: 30, left: 40 };
  const width = 600 - margin.left - margin.right;
  const height = 400 - margin.top - margin.bottom;

  // Create the SVG container
  const svg = d3
    .select("#chart")
    .append("svg")
    .attr("width", width + margin.left + margin.right)
    .attr("height", height + margin.top + margin.bottom)
    .append("g")
    .attr("transform", `translate(${margin.left},${margin.top})`);

  // Create the x and y scales
  const x = d3.scaleBand().range([0, width]).padding(0.1);
  const y = d3.scaleLinear().range([height, 0]);

  // Set the domains for the scales
  x.domain(barChartData.map((d) => d.make));
  y.domain([0, d3.max(barChartData, (d) => Math.max(d.mpg, d.attributes))]);

  // Create the bars for mpg
  svg
    .selectAll(".mpg-bar")
    .data(barChartData)
    .enter()
    .append("rect")
    .attr("class", "mpg-bar")
    .attr("x", (d) => x(d.make))
    .attr("width", x.bandwidth() / 2)
    .attr("y", (d) => y(d.mpg))
    .attr("height", (d) => height - y(d.mpg));

  // Create the bars for attributes
  svg
    .selectAll(".attributes-bar")
    .data(barChartData)
    .enter()
    .append("rect")
    .attr("class", "attributes-bar")
    .attr("x", (d) => x(d.make) + x.bandwidth() / 2)
    .attr("width", x.bandwidth() / 2)
    .attr("y", (d) => y(d.attributes))
    .attr("height", (d) => height - y(d.attributes));

  // Add x-axis
  svg
    .append("g")
    .attr("transform", `translate(0,${height})`)
    .call(d3.axisBottom(x));

  // Add y-axis
  svg.append("g").call(d3.axisLeft(y));

  // Add legend
  const legend = svg
    .append("g")
    .attr("transform", `translate(${width - 100},${height - 100})`);

  legend
    .append("rect")
    .attr("class", "mpg-bar")
    .attr("x", 0)
    .attr("width", 10)
    .attr("y", 0)
    .attr("height", 10);

  legend
    .append("text")
    .attr("x", 20)
    .attr("y", 10)
    .attr("dy", "0.35em")
    .text("mpg");

  legend
    .append("rect")
    .attr("class", "attributes-bar")
    .attr("x", 0)
    .attr("width", 10)
    .attr("y", 20)
    .attr("height", 10);

  legend
    .append("text")
    .attr("x", 20)
    .attr("y", 30)
    .attr("dy", "0.35em")
    .text("attributes");
}

// Fetch the CSV data and create the bar chart
fetchData(csvUrl).then((data) => {
  createBarChart(data);
});
